# importing modules
import sys as sys
import os 
import pandas as pd 
import matplotlib.pyplot as plt
# Getting the name of the directory where this file is present.
current = os.path.dirname(os.path.realpath(__file__))  # src
# Getting the parent directory name where the current directory is present.
parent = os.path.dirname(current) # Simulation
# Getting the grandparent directory name
gparent = os.path.dirname(parent) # RecruitmentSynchronization_SMCs
# The path where the plotExp.py is saved
mpath = gparent + '\\cellLib\\Scripts'
# appending a path
sys.path.append(mpath)
import plotExp
# The properties of traces
colors=plt.rcParams['axes.prop_cycle'].by_key()['color']
lines = ['-','--','-.',':']
markers = ['.',',','o','+','x','d']
# Figure file name and titles
figfiles=parent+'\\simFig13_r.png'
fig_title = 'Primary Fig 13 reference'
plot_title =['Voltage dependency','Transfer function']
labels = ['Original reference $Q$','CellML reference $Q$','Original reference $P$','CellML reference $P$']
# Data source
dfolder_original=parent+'\\originalData\\'
ofilenames=['Fig13A_Qr.csv','Fig13B_r.csv','Fig13A_Pr.csv']
dfilename_sim=parent+'\\simulatedData\\simFig13_r.csv'
x_var_org ='x'
y_var_org ='Curve1'
x_var_sim = ['clamp_para/V_actTest','output_18/Q','clamp_para/V_actTest']
y_vars_sim = ['output_18/Q','output_18/P_o','output_18/P_o']
x_label=['Voltage (mV)','Charge','Voltage (mV)']
y_label=['Charge','P','P']
Qmax=23.1
# Build the traces
number_trace = 2
number_plot = len(y_vars_sim)
trace = [[0] * number_trace for i in range(number_plot)]
data = pd.read_csv(dfilename_sim) 

for plotid, y_var_sim in enumerate(y_vars_sim):
   odata = pd.read_csv(dfolder_original+ofilenames[plotid])
   ox_data=odata[x_var_org].values
   oy_data=odata[y_var_org].values 
   if y_var_sim=='output_18/Q':  
      y_data=data[y_var_sim].values
   else:
      y_data=data[y_var_sim].values
   if x_var_sim[plotid]=='output_18/Q':   
       x_data=data[x_var_sim[plotid]].values
   else:
       x_data=data[x_var_sim[plotid]].values
      
   if plotid<2: 
      trace[plotid][0]={'dataX': ox_data, 'dataY': oy_data, 'lname': labels[plotid*2], 'linestyle':lines[1], 'marker':markers[0], 'linecolor':colors[plotid],'y2':False}
      trace[plotid][1]={'dataX': x_data, 'dataY': y_data, 'lname': labels[plotid*2+1], 'linestyle':lines[0], 'marker':None, 'linecolor':colors[plotid],'y2':False}
   else:
      otrace={'dataX': ox_data, 'dataY': oy_data, 'lname': labels[2], 'linestyle':lines[1], 'marker':markers[0], 'linecolor':colors[1],'y2':True}
      ntrace={'dataX': x_data, 'dataY': y_data, 'lname': labels[3], 'linestyle':lines[0], 'marker':None, 'linecolor':colors[1],'y2':True}
        
# Build the plots 
# maxH=8.75 inches, width 2.63-7.5
rows,cols = 1,2
left = 0.125  # the left side of the subplots of the figure,0.125
right = 0.9   # the right side of the subplots of the figure,0.9
bottom = 0.15  # the bottom of the subplots of the figure, 0.1
top = 0.75     # the top of the subplots of the figure 0.9
wspace = 0.5  # the amount of width reserved for space between subplots,
              # expressed as a fraction of the average axis width, 0.2
hspace = 0.1  # the amount of height reserved for space between subplots,
              # expressed as a fraction of the average axis height, 0.2
lgdfont, labelfont =10, 10
width, height= cols*3.5, rows*4
figs ={ 'width':width, 'height': height, 'rows': rows, 'cols': cols,'left':left,'bottom':bottom,'right':right,'top':top,'wspace': wspace,'hspace': hspace,'fig_title':fig_title,'title_y':1}

plots=[]
for id in range(2):    
   colid = id%2
   rowid = id//2
   if id == 0:
      lgdshow = True
      bbox_to_anchor = (1.3,1.2)
      trace[id].append(otrace)
      trace[id].append(ntrace)
   else:
      lgdshow = False
      bbox_to_anchor = None
   if id==0:      
      iplot={'rowid':rowid, 'colid':colid, 'xlabel': x_label[id], 'ylabel':y_label[id], 'twiny':True,    'ylabel2':y_label[id+1],'labelcolor':colors[1],
            'lgdshow': lgdshow, 'lgdloc':'center', 'bbox_to_anchor':bbox_to_anchor,'lgdncol': 2, 'lgdfont':lgdfont, 'labelfont': labelfont,  
            'setxlim': False, 'xmin':0, 'xmax': 1, 'setylim': False,'ymin':0, 'ymax':1, 'grid': True,    'gridaxis': 'both', 'plot_title': plot_title[id],
            'traces':trace[id]
            }
   else:
      iplot={'rowid':rowid, 'colid':colid, 'xlabel': x_label[id], 'ylabel':y_label[id+1], 'twiny':False,    'ylabel2':y_label[id],'labelcolor':colors[1],
            'lgdshow': lgdshow, 'lgdloc':'center', 'bbox_to_anchor':bbox_to_anchor,'lgdncol': 2, 'lgdfont':lgdfont, 'labelfont': labelfont,  
            'setxlim': False, 'xmin':0, 'xmax': 1, 'setylim': False,'ymin':0, 'ymax':1, 'grid': True,    'gridaxis': 'both', 'plot_title': plot_title[id],
            'traces':trace[id]
            }
   plots.append(iplot)

ids = range(len(y_vars_sim))   
subfigs={ids: plots for ids, plots in zip(ids, plots)}
fig,axs=plotExp.plotExp(figs,subfigs,figfiles)




